==> accountbook-3.0b1.tar.gz: accountbook-3.0b1/public/setting-theme.rb <==
#!/home/netsphere/bin/ruby
# -*- mode:ruby; coding:utf-8 -*-

# Q's Account Book
# Copyright (c) 2002-2005 HORIKAWA Hisashi. All rights reserved.
#   mailto:vzw00011@nifty.ne.jp
#   http://www.nslabs.jp/

# 画面テーマの選択

require "pcview.rb"

class PageAF < Wafu::ActionForm
  attr_reader :theme
  def setup()
    @theme = @app.cgi.get("theme")
  end
end

class DonePage < Wafu::Action
  def execute(af)
    @app.user.user_setting.theme_name = af.theme
    @app.user.user_setting.save!
    @app.page_out("setting-theme2.html", {})
  end
end

class DesignPage < Wafu::Action
  def get_model()
    prof = @app.user.user_setting

    candidate = []
    Dir.glob(AppConfig[:theme_local_dir] + "/*") {|path|
      path.untaint
      name = File.basename(path)
      if FileTest.directory?(path) && FileTest.file?(path + "/#{name}.css")
        candidate << {
          :name => name,
          :selected => prof.theme_name == name ? "selected" : nil
        }
      end
    }

    model = {
      :cancel => "window.location='#{SITE_URL}login.rb';",
      :theme_changed => Amrita::SanitizedString["select_stylesheet('s', '#{AppConfig[:theme_base_url]}', this[this.selectedIndex].value);"],
      :candidate => candidate,
      :stylefile => [
        {:id => nil, :filename => AppConfig[:theme_base_url] + "/base.css", :charset => "EUC-JP"},
        {
          :id => "s",
          :filename => AppConfig[:theme_base_url] + "/" +
                 (prof.theme_name ? prof.theme_name + "/" +
                                         prof.theme_name + ".css" : ""),
          :charset => "EUC-JP"}
       ],
       :newlink => "#",
       :adminlink => "#",
       :callist => [],
       :day => []
     }
     # カレンダー
     today = Date.today
     cal_hash = nil
     (today.year - 1 .. today.year).each {|y|
       cal_hash = {:year => y, :month => []}
       (1..12).each {|m|
         cal_hash[:month] << {:link => {:monlink => "#", :mon => sprintf("%02d", m)}}
       }
     }
     model[:callist] << cal_hash

     # エントリ
     day_hash = {
       :datelink => "#",
       :date => sprintf("%d.%d.%d", today.year, today.mon, today.day),
       :title => "タイトルのサンプル",
       :section => [],
       :comment => nil,
       :referer => true
     }
     day_hash[:section] << {:subtitle => "セクションのタイトルのサンプル", :body => "本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。"}
     day_hash[:section] << {:subtitle => "二つ目のセクション", :body => "セクションにタイトルがない場合。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。"}

     model[:day] << day_hash << day_hash

     return model
  end

  def execute(af)
    model = get_model()
    @app.page_out("setting-theme1.html", model)
  end
end

class DesignEditor < PCView
  def main()
    actions = {
      "ok" => [PageAF, DonePage, nil],
      "*" => [nil, DesignPage, nil]
    }
    dispatch(actions)
  end
end

if __FILE__ == $0
  DesignEditor.new.run()
end

==> accountbook-3.0.0.tar.gz: accountbook-3.0.0/public/setting-theme.rb <==
#!/home/netsphere/bin/ruby
# -*- mode:ruby; coding:utf-8 -*-

# Q's Web Account Book
# Copyright (c) 2002-2007,2010 HORIKAWA Hisashi. All rights reserved.
#   http://www.nslabs.jp/


# 画面テーマの選択

require "pcview.rb"

class PageAF < Wafu::ActionForm
  attr_reader :theme
  def setup()
    @theme = @app.cgi.get("theme")
  end
end

class DonePage < Wafu::Action
  def execute(af)
    @app.user.user_setting.theme_name = af.theme
    @app.user.user_setting.save!

    app.set_flash("notice", "notice: 画面テーマを変更しました。")
    app.redirect_to "menu.rb"
  end
end

class DesignPage < Wafu::Action
  def get_model()
    raise "AppConfig[:theme_local_dir] miss!" if !FileTest.directory?(AppConfig[:theme_local_dir])

    prof = @app.user.user_setting

    candidate = []
    Dir.glob(AppConfig[:theme_local_dir] + "/*") {|path|
      path.untaint
      name = File.basename(path)
      if FileTest.directory?(path) && FileTest.file?(path + "/#{name}.css")
        candidate << {
          :name => name,
          :selected => prof.theme_name == name ? "selected" : nil
        }
      end
    }

    model = {
      :cancel => "window.location='#{SITE_URL}menu.rb';",
      :theme_changed => Amrita::SanitizedString["select_stylesheet('s', '#{AppConfig[:theme_base_url]}', this[this.selectedIndex].value);"],
      :candidate => candidate,
      :stylefile => [
        {:id => nil, :filename => AppConfig[:theme_base_url] + "/base.css", :charset => "EUC-JP"},
        {
          :id => "s",
          :filename => AppConfig[:theme_base_url] + "/" +
                 (prof.theme_name ? prof.theme_name + "/" +
                                         prof.theme_name + ".css" : ""),
          :charset => "EUC-JP"}
       ],
       :newlink => "#",
       :adminlink => "#",
       :callist => [],
       :day => []
     }
     # カレンダー
     today = Date.today
     cal_hash = nil
     (today.year - 1 .. today.year).each {|y|
       cal_hash = {:year => y, :month => []}
       (1..12).each {|m|
         cal_hash[:month] << {:link => {:monlink => "#", :mon => sprintf("%02d", m)}}
       }
     }
     model[:callist] << cal_hash

     # エントリ
     day_hash = {
       :datelink => "#",
       :date => sprintf("%d.%d.%d", today.year, today.mon, today.day),
       :title => "タイトルのサンプル",
       :section => [],
       :comment => nil,
       :referer => true
     }
     day_hash[:section] << {:subtitle => "セクションのタイトルのサンプル", :body => "本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。"}
     day_hash[:section] << {:subtitle => "二つ目のセクション", :body => "セクションにタイトルがない場合。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。本文のサンプル。"}

     model[:day] << day_hash << day_hash

     return model
  end

  def execute(af)
    model = get_model()
    @app.page_out("setting-theme1.html", model)
  end
end

class DesignEditor < PCView
  def main()
    actions = {
      "ok" => [PageAF, DonePage, nil],
      "*" => [nil, DesignPage, nil]
    }
    dispatch(actions)
  end
end

if __FILE__ == $0
  DesignEditor.new.run()
end
